import Vue from 'vue';
import VueRouter from 'vue-router';

Vue.use(VueRouter);

const routes = [
  {
    path: '/admin',
    name: 'admin',
    redirect: '/admin/home',
    component: () => import('@/components/Layout.vue'),
    children: [
      {
        path: 'home',
        name: 'adminHome',
        component: () => import('@/views/Home.vue'),
      },
      {
        path: 'room',
        name: 'adminRoom',
        component: () => import('@/views/Room.vue'),
      },
      {
        path: 'edit',
        name: 'adminEdit',
        component: () => import('@/views/Edit.vue'),
      },
      {
        path: '*',
        redirect: '/admin/home',
      },
    ],
  },
  {
    path: '*',
    redirect: '/admin/home',
  },
];

export async function genRouter() {
  try {
    let _routes = [];

    const modules = await Promise.all([
      import('workforce/router'),
      import('network/router'),
    ]);
    modules.forEach((mod) => {
      _routes = mod.routes.concat(_routes);
    });
    _routes = _routes.concat(routes);

    const router = new VueRouter({
      mode: 'history',
      routes: _routes,
    });
    return router;
  } catch (error) {
    console.error('load router fail', error);
    return [];
  }
}
