import Vue from 'vue';
import Vuex from 'vuex';
import modules from './modules';

Vue.use(Vuex);

const baseStore = {
  state: {
    count: 0,
  },
  mutations: {
    increment(state) {
      state.count++;
    },
  },
  modules,
};

export async function genStore() {
  try {
    const modules = await Promise.all([
      import('workforce/store'),
      import('network/store'),
    ]);
    modules.forEach((mod) => {
      Object.assign(baseStore.modules, mod.modules);
    });
    return new Vuex.Store(baseStore);
  } catch (error) {
    console.error('load store fail', error);
    return new Vuex.Store(baseStore);
  }
}
